==> cbrpager_0.9.22.orig.tar.gz: cbrpager-0.9.22/src/callbacks.h <==
#include <gnome.h>


gboolean
on_main_canvas_button_press_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_main_canvas_button_release_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_back_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_zoom_out_btn_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_zoom_fit_btn_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_zoom_in_btn_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_open_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_quit_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_MainWindow_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);


void
on_begin_btn_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_next_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_last_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);


void
on_pref_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_conf_cancel_btn_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_conf_save_btn_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_config_window_realize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_MainWindow_realize                  (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_main_canvas_key_press_event         (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_MainWindow_size_allocate            (GtkWidget       *widget,
                                        GdkRectangle    *allocation,
                                        gpointer         user_data);

void
on_zoom_orig_btn_clicked               (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_nav_window_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_advance_1_page1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_advance_2_pages1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_go_to_end1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_backup_1_page1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_backup_2_pages1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_go_to_start1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoom_to_fit1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_enlarge1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_reduce1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_original_size1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_configuration_window1_activate      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoom_width_btn_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_fit_to_page_width1_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_list_tbtn_clicked              (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_conf_notebook_key_press_event       (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

gboolean
on_conf_notebook_key_release_event     (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_conf_accel_tview_realize            (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_conf_accel_tview_cursor_changed     (GtkTreeView     *treeview,
                                        gpointer         user_data);

void
on_nav_window_realize                  (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_scroll_left_btn_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_scroll_right_btn_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_scroll_up_btn_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_scroll_down_btn_clicked             (GtkButton       *button,
                                        gpointer         user_data);

==> cbrpager_0.9.23-1.tar.gz: cbrpager-0.9.23/src/callbacks.h <==
#include <gtk/gtk.h>
#include "gtkimageview.h"



gboolean
on_main_canvas_button_press_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_main_canvas_button_release_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_main_canvas_motion_event            (GtkWidget       *widget,
					GdkEventMotion  *event,
					gpointer         user_data);

void
on_back_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_zoom_out_btn_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_zoom_fit_btn_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_zoom_in_btn_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_open_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);
void
on_open_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_quit_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);
void
on_quit_activate                       (GtkMenuItem     *menuitem,
					gpointer         user_data);

gboolean
on_MainWindow_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);


void
on_begin_btn_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_next_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_last_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);


void
on_pref_btn_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_conf_cancel_btn_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_conf_save_btn_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_config_window_realize               (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_MainWindow_realize                  (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_main_canvas_key_press_event         (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);
gboolean
on_main_canvas_key_release_event       (GtkWidget       *widget,
					GdkEventKey     *event,
					gpointer         user_data);

void
on_MainWindow_size_allocate            (GtkWidget       *widget,
                                        GdkRectangle    *allocation,
                                        gpointer         user_data);

void
on_zoom_orig_btn_clicked               (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_nav_window_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_advance_1_page1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_advance_2_pages1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_go_to_end1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_backup_1_page1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_backup_2_pages1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_go_to_start1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoom_to_fit1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_enlarge1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_reduce1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_original_size1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_configuration_window1_activate      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoom_width_btn_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_fit_to_page_width1_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_list_tbtn_clicked              (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_conf_notebook_key_press_event       (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

gboolean
on_conf_notebook_key_release_event     (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_conf_accel_tview_realize            (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_conf_accel_tview_cursor_changed     (GtkTreeView     *treeview,
                                        gpointer         user_data);

void
on_nav_window_realize                  (GtkWidget       *widget,
                                        gpointer         user_data);
void
on_rotate_btn_clicked                  (GtkButton       *button,
					gpointer         user_data);
void
on_fullscreen_btn_clicked              (GtkButton       *button,
					gpointer         user_data);
void
on_about_box_activate                  (GtkMenuItem     *menu_item,
					gpointer         user_data);
void
on_goto_page_activate                  (GtkMenuItem     *menu_item,
					gpointer         user_data);
void
on_fullscreen_activate                 (GtkMenuItem     *menu_item,
					gpointer         user_data);
void
on_toggle_btn_clicked                  (GtkButton       *button,
					gpointer         user_data);
